bbonev          Fri Jan 26 16:25:09 2001 EDT

  Modified files:              
    /php4/ext/vpopmail  php_vpopmail.c 
  Log:
  # fixed protos in comments for *_ex functions
  
Index: php4/ext/vpopmail/php_vpopmail.c
diff -u php4/ext/vpopmail/php_vpopmail.c:1.5 php4/ext/vpopmail/php_vpopmail.c:1.6
--- php4/ext/vpopmail/php_vpopmail.c:1.5        Tue Jan 23 13:46:03 2001
+++ php4/ext/vpopmail/php_vpopmail.c    Fri Jan 26 16:25:08 2001
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: php_vpopmail.c,v 1.5 2001/01/23 21:46:03 bbonev Exp $ */
+/* $Id: php_vpopmail.c,v 1.6 2001/01/27 00:25:08 bbonev Exp $ */
 
 /* TODO: move to config.m4 when support for old versions is ready or just
  * don't support rather old vpopmail. current version must bail out if
@@ -285,7 +285,7 @@
  * Domain management functions - exec
  */
 
-/* {{{ proto int vpopmail_add_domain_ex(string domain, string passwd [, string quota 
[, string bounce [, bool apop]]])
+/* {{{ proto bool vpopmail_add_domain_ex(string domain, string passwd [, string quota 
+[, string bounce [, bool apop]]])
    Add a new virtual domain */
 PHP_FUNCTION(vpopmail_add_domain_ex) {
        zval **domain, **passwd, **quota, **bounce, **apop;
@@ -411,7 +411,7 @@
 }
 /* }}} */
 
-/* {{{ proto int vpopmail_del_domain_ex(string domain)
+/* {{{ proto bool vpopmail_del_domain_ex(string domain)
    Delete a virtual domain */
 PHP_FUNCTION(vpopmail_del_domain_ex) {
        zval **domain;
@@ -455,7 +455,7 @@
 }
 /* }}} */
 
 /* {{{ proto int vpopmail_add_alias_domain_ex(string olddomain, string newdomain)
    Add alias to an existing virtual domain */
 PHP_FUNCTION(vpopmail_add_alias_domain_ex) {
        zval **olddomain, **newdomain;
@@ -455,7 +455,7 @@
 /* }}} */
 
-/* {{{ proto int vpopmail_add_alias_domain_ex(string olddomain, string newdomain)
+/* {{{ proto bool vpopmail_add_alias_domain_ex(string olddomain, string newdomain)
    Add alias to an existing virtual domain */
 PHP_FUNCTION(vpopmail_add_alias_domain_ex) {



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
To contact the list administrators, e-mail: [EMAIL PROTECTED]

Reply via email to